appobject.py
changeset 2476 1294a6bdf3bf
parent 2144 51c84d585456
child 2613 5e19c2bb370e
--- a/appobject.py	Fri Jul 24 13:50:59 2009 +0200
+++ b/appobject.py	Fri Jul 24 14:33:37 2009 +0200
@@ -40,11 +40,11 @@
 
     At registration time, the following attributes are set on the class:
     :vreg:
-      the application's registry
+      the instance's registry
     :schema:
-      the application's schema
+      the instance's schema
     :config:
-      the application's configuration
+      the instance's configuration
 
     At instantiation time, the following attributes are set on the instance:
     :req:
@@ -276,7 +276,7 @@
         return output.getvalue()
 
     def format_date(self, date, date_format=None, time=False):
         """return a string for a date time according to application's
         configuration
         """
         if date:
@@ -289,7 +289,7 @@
         return u''
 
     def format_time(self, time):
         """return a string for a time according to application's
         configuration
         """
         if time:
@@ -297,7 +297,7 @@
         return u''
 
     def format_float(self, num):
         """return a string for floating point number according to application's
         configuration
         """
         if num:
@@ -276,7 +276,7 @@
 
     def format_date(self, date, date_format=None, time=False):
-        """return a string for a date time according to application's
+        """return a string for a date time according to instance's
         configuration
         """
@@ -289,7 +289,7 @@
 
     def format_time(self, time):
-        """return a string for a time according to application's
+        """return a string for a time according to instance's
         configuration
         """
@@ -297,7 +297,7 @@
 
     def format_float(self, num):
-        """return a string for floating point number according to application's
+        """return a string for floating point number according to instance's
         configuration
         """